@@ -175,8 +175,13 @@ class RelatedField(Field):
                 value = attribute_instance.serializable_value(self.source_attrs[-1])
                 if is_simple_callable(value):
                     # Handle edge case where the relationship `source` argument
-                    # points to a `get_relationship()` method on the model
-                    value = value().pk
+                    # points to a `get_relationship()` method on the model.
+                    value = value()
+
+                # Handle edge case where relationship `source` argument points
+                # to an instance instead of a pk (e.g., a `@property`).
+                value = getattr(value, 'pk', value)
+
                 return PKOnlyObject(pk=value)
             except AttributeError:
                 pass
@@ -252,8 +257,9 @@ class PrimaryKeyRelatedField(RelatedField):
     def to_internal_value(self, data):
         if self.pk_field is not None:
             data = self.pk_field.to_internal_value(data)
+        queryset = self.get_queryset()
         try:
-            return self.get_queryset().get(pk=data)
+            return queryset.get(pk=data)
         except ObjectDoesNotExist:
             self.fail('does_not_exist', pk_value=data)
         except (TypeError, ValueError):
@@ -449,8 +455,9 @@ class SlugRelatedField(RelatedField):
         super().__init__(**kwargs)
 
     def to_internal_value(self, data):
+        queryset = self.get_queryset()
         try:
-            return self.get_queryset().get(**{self.slug_field: data})
+            return queryset.get(**{self.slug_field: data})
         except ObjectDoesNotExist:
             self.fail('does_not_exist', slug_name=self.slug_field, value=smart_str(data))
         except (TypeError, ValueError):
